/*
*************************************************************************************************
*	  					ILI9320 262k color Graphical LCD Display Driver in Portrait
*										All Rights Reserved
* File name		: ILI9320P_8BIT.h
* Programmer 	: John Leung, TechToys Co. Hong Kong
* Web presence  : www.TechToys.com.hk
* Note			: 
* Language		: RealView Compiler Demo version from Keil
* Hardware		: LPC2103
* Date			: 13 Jan 2008
*************************************************************************************************
*										DESCRIPTION
*
* This module provides an interface to TY240_240320 262k color graphical LCD module of 240*320dots
* Display controller chip is ILI9320
* 8-bit data bus mode 8080
*
* LCD pinout function on PCB (TY240_240320_BO) summarized as below 
*
* --------- LCD			MCU -----------------
* pin 40	n.c.		- NOT used here
* pin 38 	VBATT+ 		- 3.3V supply for backlight
* pin 36	n.c.  		- NOT used here
* pin 34:22	DB[15:9]	- P0.[15:8]
* pin 18	/RES		- RST of the system (MAX811)
* pin 16	RS			- P0.20
* pin 14	CS			- P0.19
* pin 12	RD			- P0.17
* pin 10	WR			- P0.18
* pin 8		n.c.		- NOT used
* pin 6		Vdd			- 3.3V
* pin 4		GND			- GND
* pin 2		EN			- P0.21
***********************************************************************************************
*/
#ifndef _ILI9320P_8BIT_H
#define _ILI9320P_8BIT_H

#include <LPC2103.H>

typedef unsigned char 		INT8U;
typedef unsigned short		INT16U;
typedef unsigned char		BOOLEAN;


typedef union _SHORT_VAL
{
    INT16U Val;
    INT8U v[2];
    struct
    {
        INT8U LB;
        INT8U HB;
    } byte;
    struct
    {
        unsigned char b0:1;
        unsigned char b1:1;
        unsigned char b2:1;
        unsigned char b3:1;
        unsigned char b4:1;
        unsigned char b5:1;
        unsigned char b6:1;
        unsigned char b7:1;
        unsigned char b8:1;
        unsigned char b9:1;
        unsigned char b10:1;
        unsigned char b11:1;
        unsigned char b12:1;
        unsigned char b13:1;
        unsigned char b14:1;
        unsigned char b15:1;
    } bits;
} SHORT_VAL;


// Horizontal and vertical screen size
#define SCREEN_HOR_SIZE    240
#define SCREEN_VER_SIZE    320


/*
***********************************************************************************************
*								Pin definition, RealView specific
*					Hardware: LPC2103, with color LCD pinout mapped to GPIO
***********************************************************************************************
*/
typedef struct {
	unsigned long 	    :8;	
 	unsigned long DAT	:8; //Data = P0.[15:8]
	unsigned long 		:1;	//P0.16 not used for LCD
	unsigned long RD	:1;	//P0.17=RD
	unsigned long WR	:1; //P0.18=WR
	unsigned long CS	:1; //P0.19=CS
	unsigned long RS	:1; //P0.20=RS
	unsigned long LED	:1; //P0.21=EN for LED backlight
	unsigned long 		:10;
}__cDisp_bits;

#define cDispPIN_bit          (*((volatile __cDisp_bits *) 0xE0028000))
#define cDispSET_bit          (*((volatile __cDisp_bits *) 0xE0028004))
#define cDispDIR_bit          (*((volatile __cDisp_bits *) 0xE0028008))
#define cDispCLR_bit          (*((volatile __cDisp_bits *) 0xE002800C))


/*
***********************************************************************************************
*								 		COLOR CODES

		 

***********************************************************************************************
*/
                                  	//RRRRRGGGGGGBBBBB 
#define BLACK              0x0000	//0000000000000000
#define BRIGHTBLUE         0x001F	//0000000000011111
#define BRIGHTGREEN        0x07E0	//0000011111100000
#define BRIGHTCYAN         0x07FF	//0000011111111111
#define BRIGHTRED          0xF800	//1111100000000000
#define BRIGHTMAGENTA      0xF81F	//1111100000011111
#define BRIGHTYELLOW       0xFFE0	//1111111111100000
#define BLUE               0x0010	//0000000000010000
#define GREEN              0x0400	//0000010000000000
#define CYAN               0x0410	//0000010000010000
#define RED                0x8000	//100000000000000
/*
#define MAGENTA            (INT16U)1000000000010000Y
#define BROWN              (INT16U)1111110000000000Y
#define LIGHTGRAY          (INT16U)1000010000010000Y
#define DARKGRAY           (INT16U)0100001000001000Y
#define LIGHTBLUE          (INT16U)1000010000011111Y
#define LIGHTGREEN         (INT16U)1000011111110000Y
#define LIGHTCYAN          (INT16U)1000011111111111Y
#define LIGHTRED           (INT16U)1111110000010000Y
#define LIGHTMAGENTA       (INT16U)1111110000011111Y
#define YELLOW             (INT16U)1111111111110000Y
*/
#define WHITE              0xFFFF	//1111111111111111Y



/*
***********************************************************************************************
*									FUNCTION PROTOTYPES
***********************************************************************************************
*/
void cDispInit(void);


/*
***********************************************************************************************
*									FUNCTION PROTOTYPES
*									 HARDWARE SPECIFIC
***********************************************************************************************
*/

void cDispClearDevice(INT16U color);
void cDispInitPort(void);
void cDispWrCmd(INT8U cmd);
void cDispWrDat(INT8U byte1, INT8U byte0);

#endif // _ILI9320P_8BIT_H
